@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/bash -e
 clear
 
 echo " _     _ _               _          ___  ____  "
@@ -9,15 +9,13 @@ echo "|_____|_|_.__/ \___|_|   \__|\__, |\___/|____/ "
 echo "                             |___/             "
 echo "By using this script, and by running LibertyOS, you are agreeing to the terms outlined in the LICENSE."
 echo "Installing rustup..."
+if ! rustc --version; then
 curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh
-echo "Installing libraries for x86_64-unknown-linux-gnu..."
-rustup target add x86_64-unknown-linux-gnu
-echo "Installing the llvm-tools-preview component..."
-rustup component add llvm-tools-preview
+else
+echo "Rust already installed"
+fi
 echo "Installing the bootimage crate..."
 cargo install bootimage
-echo "Setting the default Rust toolchain to the nightly build..."
-rustup default nightly
 echo "Your system should now be correctly configured to build and run LibertyOS."
 echo "To launch the kernel in a VM, use the cargo run command (requires QEMU)"
 echo "To compile LibertyOS, for use in another VM software, or to run LibertyOS on real hardware, simply use the cargo build command."
