@@ -1,10 +1,19 @@
 // clock.rs
+//
+// Basic implementation of time-keeping for the LibertyOS kernel.
+
+/*
+	IMPORTS
+*/
 
 use crate::cmos::CMOS;
 use crate::time;
 
+
 const D_BEFORE_MON: [u64; 13] = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];
 
+
+// Real-time
 pub fn realtime() -> f64
 {
 	let rtc = CMOS::new().rtc();
@@ -18,12 +27,15 @@ pub fn realtime() -> f64
 	(timestamp as f64) + fract
 }
 
+
+// Up-time
 pub fn uptime() -> f64
 {
 	time::time_between_ticks() * time::tick() as f64
 }
 
 
+// Day before year
 fn d_before_yr(year: u64) -> u64
 {
 	(1970..year).fold(0, |days, y|
@@ -39,6 +51,8 @@ fn d_before_yr(year: u64) -> u64
 	})
 }
 
+
+// Day before month
 fn d_before_mon(year: u64, month: u64) -> u64
 {
 	let leapd = leapyr(year) && month > 2;
@@ -52,6 +66,8 @@ fn d_before_mon(year: u64, month: u64) -> u64
 	}
 }
 
+
+// Leap year
 fn leapyr(year: u64) -> bool
 {
 	if year % 4 != 0
